@@ -1,12 +1,18 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render documents into HTML
-$Statocles::Page::Document::VERSION = '0.008';
+$Statocles::Page::Document::VERSION = '0.009';
 use Statocles::Class;
 with 'Statocles::Page';
 use Text::Markdown;
 use Statocles::Template;
 
 
+has published => (
+    is => 'ro',
+    isa => InstanceOf['Time::Piece'],
+);
+
+
 has document => (
     is => 'ro',
     isa => InstanceOf['Statocles::Document'],
@@ -34,12 +40,14 @@ sub render {
         content => $self->content,
         path => $self->path,
         app => $self->app,
+        published => $self->published,
     );
     return $self->layout->render(
         %args,
         content => $content,
         path => $self->path,
         app => $self->app,
+        published => $self->published,
     );
 }
 
@@ -55,7 +63,7 @@ Statocles::Page::Document - Render documents into HTML
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 DESCRIPTION
 
@@ -63,6 +71,10 @@ This page class takes a single L<document|Statocles::Document> and renders it as
 
 =head1 ATTRIBUTES
 
+=head2 published
+
+The publish date/time of this page. A L<Time::Piece> object.
+
 =head2 document
 
 The L<document|Statocles::Document> this page will render.
