@@ -1,11 +1,13 @@
 package Statocles::Store;
 # ABSTRACT: A repository for Documents and Pages
-$Statocles::Store::VERSION = '0.008';
+$Statocles::Store::VERSION = '0.009';
 use Statocles::Class;
 use Statocles::Document;
 use YAML;
 use File::Spec::Functions qw( splitdir );
 
+my $DT_FORMAT = '%Y-%m-%d %H:%M:%S';
+
 
 has path => (
     is => 'ro',
@@ -68,6 +70,14 @@ sub read_document {
         $doc->{content} = $buffer;
     }
 
+    return $self->_thaw_document( $doc );
+}
+
+sub _thaw_document {
+    my ( $self, $doc ) = @_;
+    if ( exists $doc->{last_modified} ) {
+        $doc->{last_modified} = Time::Piece->strptime( $doc->{last_modified}, $DT_FORMAT );
+    }
     return $doc;
 }
 
@@ -81,7 +91,7 @@ sub write_document {
 
     $doc = { %{ $doc } }; # Shallow copy for safety
     my $content = delete $doc->{content};
-    my $header = YAML::Dump( $doc );
+    my $header = YAML::Dump( $self->_freeze_document( $doc ) );
     chomp $header;
 
     my $full_path = $self->path->child( $path );
@@ -90,6 +100,14 @@ sub write_document {
     return $full_path;
 }
 
+sub _freeze_document {
+    my ( $self, $doc ) = @_;
+    if ( exists $doc->{last_modified} ) {
+        $doc->{last_modified} = $doc->{last_modified}->strftime( $DT_FORMAT );
+    }
+    return $doc;
+}
+
 
 sub write_page {
     my ( $self, $path, $html ) = @_;
@@ -110,7 +128,7 @@ Statocles::Store - A repository for Documents and Pages
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 DESCRIPTION
 
